adjust_refetch_metadata

Function adjust_refetch_metadata 

pub fn adjust_refetch_metadata(
    previous: &ColumnMetadata,
    current: &mut ColumnMetadata,
) -> bool
When the same query is re-executed after a column’s data type changed to CLOB/BLOB but the previous execution fetched the column as a char/raw type, the server streams the data as LONG/LONG RAW (same as a define of CLOB/BLOB as string/bytes); the fetch metadata must follow (reference impl/thin/messages/base.pyx:820-845 _adjust_metadata). Returns true when the metadata was adjusted.