Direct Path Load (DPL) protocol support.
Implements the three TTC functions used by python-oracledb’s
Connection.direct_path_load():
- function 128 — direct path prepare (send table/column names, receive server-side column metadata and a direct path cursor id),
- function 129 — direct path load stream (column-array piece stream),
- function 130 — direct path op (FINISH commits, ABORT discards).
The builders/parsers mirror impl/thin/messages/direct_path_*.pyx of the
python-oracledb v4.0.1 reference and are validated against golden wire
captures in tests/golden/. The batch state machine mirrors
impl/base/batch_load_manager.pyx.
Re-exports
pub use parse_direct_path_simple_response as parse_direct_path_load_stream_response;pub use parse_direct_path_simple_response as parse_direct_path_op_response;pub use parse_direct_path_simple_response_with_limits as parse_direct_path_load_stream_response_with_limits;pub use parse_direct_path_simple_response_with_limits as parse_direct_path_op_response_with_limits;
Structs
- Batch
Load State - Batch/chunk state machine shared by
executemanyingestion and direct path load. Port ofBatchLoadManager/DataFrameBatchLoadManager(impl/base/batch_load_manager.pyx). - Direct
Path Piece - A finalized direct path piece, ready to be written to a load stream message.
- Direct
Path Prepare Result - Direct
Path Stream - Result of encoding one batch of rows into the piece stream format.
Enums
- Direct
Path Column Value - One column value of a direct path load row, already converted to the
Oracle-facing intermediate form (mirrors the reference’s
OracleData).
Constants
- TNS_
DPLS_ MAX_ MESSAGE_ SIZE - TNS_
DPLS_ MAX_ PIECE_ SIZE - TNS_
DPLS_ MAX_ SHORT_ LENGTH - TNS_
DPLS_ ROW_ HEADER_ FAST_ PIECE - TNS_
DPLS_ ROW_ HEADER_ FAST_ ROW - TNS_
DPLS_ ROW_ HEADER_ FIRST - TNS_
DPLS_ ROW_ HEADER_ LAST - TNS_
DPLS_ ROW_ HEADER_ SPLIT_ WITH_ NEXT - TNS_
DPLS_ ROW_ HEADER_ SPLIT_ WITH_ PREV - TNS_
DPP_ OP_ CODE_ LOAD - TNS_
DP_ INTERFACE_ VERSION - TNS_
DP_ OP_ ABORT - TNS_
DP_ OP_ FINISH - TNS_
DP_ STREAM_ VERSION - TNS_
FUNC_ DIRECT_ PATH_ LOAD_ STREAM - TNS_
FUNC_ DIRECT_ PATH_ OP - TNS_
FUNC_ DIRECT_ PATH_ PREPARE
Functions
- build_
direct_ path_ load_ stream_ payload - Builds the payload for TTC function 129 (direct path load stream).
- build_
direct_ path_ op_ payload - Builds the payload for TTC function 130 (direct path op).
- build_
direct_ path_ prepare_ payload - Builds the payload for TTC function 128 (direct path prepare).
- encode_
direct_ path_ rows - Encodes a batch of rows into direct path pieces.
- parse_
direct_ path_ prepare_ response - Parses the response to TTC function 128 (direct path prepare).
- parse_
direct_ path_ prepare_ response_ with_ limits - parse_
direct_ path_ simple_ response - Parses the response to TTC functions 129 and 130 (both return the same shape: a ub2 count of out values that are each skipped).
- parse_
direct_ path_ simple_ response_ with_ limits