#[non_exhaustive]pub enum WalletError {
FileMissing(String),
Io {
path: String,
source: Error,
},
Pem(String),
NoCertificates,
Sso(String),
SsoNotEnabled,
UnsupportedFormat {
format: &'static str,
},
}Expand description
Errors raised while resolving or reading a wallet.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FileMissing(String)
The wallet directory did not contain the expected file.
Io
An I/O error occurred reading the wallet.
Pem(String)
The PEM content could not be parsed.
NoCertificates
The wallet contained no usable trust-anchor certificates.
Sso(String)
SSO (cwallet.sso) parsing failure (experimental).
SsoNotEnabled
SSO support is not compiled in.
UnsupportedFormat
A recognized wallet file is present but this thin build does not support the format.